@@ -14,6 +14,7 @@ from cognite.client._api.login import LoginAPI
 from cognite.client._api.raw import RawAPI
 from cognite.client._api.relationships import RelationshipsAPI
 from cognite.client._api.sequences import SequencesAPI
+from cognite.client._api.templates import TemplatesAPI
 from cognite.client._api.three_d import ThreeDAPI
 from cognite.client._api.time_series import TimeSeriesAPI
 from cognite.client._api_client import APIClient
@@ -35,6 +36,7 @@ class CogniteClient:
         max_workers (int): Max number of workers to spawn when parallelizing data fetching. Defaults to 10.
         headers (Dict): Additional headers to add to all requests.
         timeout (int): Timeout on requests sent to the api. Defaults to 30 seconds.
+        proxies (Dict[str, str]): Dictionary mapping from protocol to url. e.g. {"https": "http://10.10.1.10:1080"}
         token (Union[str, Callable[[], str]]): A jwt or method which takes no arguments and returns a jwt to use for authentication.
             This will override any api-key set.
         token_url (str): Optional url to use for token generation.
@@ -56,12 +58,14 @@ class CogniteClient:
     def __init__(
         self,
         api_key: Optional[str] = None,
+        api_subversion: Optional[str] = None,
         project: Optional[str] = None,
         client_name: Optional[str] = None,
         base_url: Optional[str] = None,
         max_workers: Optional[int] = None,
         headers: Optional[Dict[str, str]] = None,
         timeout: Optional[int] = None,
+        proxies: Optional[Dict[str, str]] = None,
         token: Optional[Union[str, Callable[[], str], None]] = None,
         token_url: Optional[str] = None,
         token_client_id: Optional[str] = None,
@@ -73,12 +77,14 @@ class CogniteClient:
     ):
         self._config = ClientConfig(
             api_key=api_key,
+            api_subversion=api_subversion,
             project=project,
             client_name=client_name,
             base_url=base_url,
             max_workers=max_workers,
             headers=headers,
             timeout=timeout,
+            proxies=proxies,
             token=token,
             token_url=token_url,
             token_client_id=token_client_id,
@@ -104,6 +110,7 @@ class CogniteClient:
         self.labels = LabelsAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
         self.relationships = RelationshipsAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
         self.entity_matching = EntityMatchingAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
+        self.templates = TemplatesAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
         self._api_client = APIClient(self._config, cognite_client=self)
 
     def get(self, url: str, params: Dict[str, Any] = None, headers: Dict[str, Any] = None):
